@@ -15,7 +15,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
 	and is copyrighted. Of course, we do not guarantee that the software
 	works and are not responsible for any damage you may cause or have.
 
-$Id: aic.c,v 1.25 2004/08/28 19:59:29 beerli Exp $ 
+$Id: aic.c 175 2005-12-02 14:51:23Z beerli $ 
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -129,7 +129,6 @@ void aic_score_driver(aic_struct *aic, MYREAL mle, MYREAL mleaic, nr_fmt *nr, wo
 	
     savecustm = (char *) mycalloc (2 * world->numpop2, sizeof (char));
     savecustm2 =  savecustm + world->numpop2;
-	
     memcpy (savecustm, world->options->custm2, sizeof (char) * nr->numpop2);
     memcpy (savecustm2, world->options->custm, sizeof (char) * nr->numpop2);
 	
@@ -202,7 +201,7 @@ void aic_print_driver(aic_fmt *aicvec, MYREAL mleaic, long aicnum, nr_fmt *nr, w
                  reshuffle (temppattern, aicvec[i].pattern, nr->numpop),
                  aicvec[i].aic, aicvec[i].numparam, aicvec[i].mle,
                  aicvec[i].lrt, aicvec[i].prob, aicvec[i].probcorr);
-        if (aicvec[i].aic == mleaic && !mldone)
+        if ((aicvec[i].aic - mleaic > DBL_EPSILON) && !mldone)
         {
             mldone = TRUE;
             FPRINTF (world->outfile, "%-*.*s %53.53s\n",
@@ -225,12 +224,12 @@ akaike_information (world_fmt * world, long *Gmax)
     aic_struct aic;
     nr_fmt *nr;
     long kind = world->loci > 1 ? MULTILOCUS : SINGLELOCUS;
-    long repstop;
-    long repstart;
+    long repstop=0;
+    long repstart=0;
 	
     MYREAL mleaic;
     MYREAL mle;
-    boolean multilocus;
+    boolean multilocus=FALSE;
 	
     char *temppattern;
 	
@@ -273,10 +272,11 @@ akaike_information (world_fmt * world, long *Gmax)
     aic_print_driver(aic.aicvec, mleaic, aic.aicnum, nr, world);
 	
     free (aic.aicvec);
-    fflush (world->outfile);
+    (void) fflush (world->outfile);
     free (aic.param0);
     free (temppattern);
     destroy_nr (nr, world);
+    free(nr);
 }
 
 ///
@@ -320,7 +320,7 @@ void fast_aic_score (aic_fmt ** aicvec, long *aicnum, nr_fmt * nr,
         resynchronize_param (nr->world);
         if ((legal = legal_pattern (nr->world->options->custm2, nr->numpop)))
         {
-            do_profiles (nr->world, nr, &likes, &normd, PROFILE,
+            (void) do_profiles (nr->world, nr, &likes, &normd, PROFILE,
                          nr->world->rep, nr->world->repkind);
             aic = -2. * nr->llike + 2. * freeparam;
             best[m].aic = aic;
@@ -333,7 +333,7 @@ void fast_aic_score (aic_fmt ** aicvec, long *aicnum, nr_fmt * nr,
             if (nr->world->options->progress)
                 FPRINTF (stdout, "           F   %s %20s\n",
                          reshuffle (temppattern, custm2, nr->numpop), "-----");
-            fflush (stdout);
+            (void) fflush (stdout);
             if (nr->world->options->writelog)
                 FPRINTF (nr->world->options->logfile, "           F   %s %20s\n",
                          reshuffle (temppattern, custm2, nr->numpop), "-----");
@@ -350,6 +350,7 @@ void fast_aic_score (aic_fmt ** aicvec, long *aicnum, nr_fmt * nr,
         }
     }
     free (best);
+    free(scustm2);
 }
 
 /// add model and AIC score to the list of models for the final printing
@@ -439,7 +440,7 @@ print_progress_aic(boolean add
                      prob,
                      probcorr);
     }
-    fflush (stdout);
+    (void) fflush (stdout);
     free(temppattern);
 }
 
@@ -508,7 +509,7 @@ aic_score (aic_fmt ** aicvec, long *aicnum, nr_fmt * nr,
 		
         if ((legal = legal_pattern (nr->world->options->custm2, nr->numpop)))
         {
-            do_profiles (nr->world, nr, &likes, &normd, PROFILE,
+            (void) do_profiles (nr->world, nr, &likes, &normd, PROFILE,
                          nr->world->rep, nr->world->repkind);
 			
             add_aiclist(migtype, numparam, freeparam, remainnum, zero, m, param0,
@@ -558,7 +559,7 @@ check_numparam (long which, long migtype, worldoption_fmt * options,
 boolean
 legal_pattern (char *matrix, long numpop)
 {
-    long from, to, i;
+    long from=0, to=0, i;
     MYREAL summ = -1;
     long oldto;
     for (i = 0; i < numpop; i++)
@@ -572,14 +573,14 @@ legal_pattern (char *matrix, long numpop)
         m2mm (i, numpop, &from, &to);
         if (oldto != to)
         {
-            if (summ == 0)
+            if (summ < DBL_EPSILON)
                 return FALSE;
             oldto = to;
             summ = 0;
         }
-        summ += (matrix[i] != '0') + (matrix[mm2m (to, from, numpop)] != '0');
+        summ += (MYREAL) (matrix[i] != '0') + (MYREAL) (matrix[mm2m (to, from, numpop)] != '0');
     }
-    if (summ == 0)
+    if (summ < DBL_EPSILON)
         return FALSE;
     return TRUE;
 }
@@ -614,7 +615,7 @@ long find_paramnum(world_fmt *world, char *connect)
     else
 	{
         temp1 = (char *) mycalloc(strlen(connect)+1, sizeof(char));
-        temp2 = (char *) mycalloc(strlen(connect)+1, sizeof(char));
+        //temp2 = (char *) mycalloc(strlen(connect)+1, sizeof(char));
         temp = (char *) mycalloc(strlen(connect)+1, sizeof(char));
         t = temp;
         strcpy(temp1,connect);
@@ -647,7 +648,7 @@ long find_paramnum(world_fmt *world, char *connect)
         total -= mss;
         free(temp);
         free(temp1);
-        free(temp2);
+        //free(temp2);
 	}
     return total;
 }
