@@ -15,7 +15,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
     works and are not responsible for any damage you may cause or have.
 
 
- $Id: bayes.c 215 2006-01-03 00:03:51Z beerli $
+ $Id: bayes.c 266 2006-02-19 18:09:34Z beerli $
     */
 /*! \file bayes.c 
 
@@ -626,14 +626,14 @@ bayes_update (world_fmt * world)
     bayes_fmt   *bayes = world->bayes;
     
 
-    const boolean   log = (myID==MASTER && world->options->progress && world->heat == 1.0);
+    const boolean   writelog = (myID==MASTER && world->options->progress && world->heat == 1.0);
     const MYREAL      updateratio = world->options->updateratio;
     const boolean verbose = world->heat>1-EPSILON && myID==MASTER && world->options->verbose;
 
     
     // progress reporter nested here so that we do need to ask whether we run in Bayes mode or not
     count++;
-    if(log && (count % 100000) == 0)
+    if(writelog && (count % 100000) == 0)
     {
         bayes_progress(world);
     }    
@@ -1331,13 +1331,14 @@ bayes_progress(world_fmt *world)
 /// adjusts the allocations for the histogram bins for the current locus 
 void adjust_bayes_bins(world_fmt * world, long locus)
 {
-    long pa;
-    long np = world->numpop2 + (world->bayes->mu ? 1 : 0);
-    bayeshistogram_fmt *hist = &(world->bayes->histogram[locus]);
-    hist->binsum = 0;
-    for(pa=0; pa < np; pa++)
+  MYREAL dif = 0.;
+  long pa;
+  long np = world->numpop2 + (world->bayes->mu ? 1 : 0);
+  bayeshistogram_fmt *hist = &(world->bayes->histogram[locus]);
+  hist->binsum = 0;
+  for(pa=0; pa < np; pa++)
     {
-        // if custom migration matrix is set to zero, zero the bins else set it
+      // if custom migration matrix is set to zero, zero the bins else set it
       if(pa < world->numpop2)
 	{
 	  if(strchr("0c",world->options->custm2[pa]))
@@ -1346,22 +1347,31 @@ void adjust_bayes_bins(world_fmt * world, long locus)
 	    }
 	  else
 	    {
-	      hist->bins[pa] = (long) (0.5 + (hist->maxima[pa] - hist->minima[pa]) / world->bayes->deltahist[pa]) ;
-	      //fprintf(stdout,"%i> LOCUS: bins[%li]=%li = (%f - %f) /%f \n",myID,pa,hist->bins[pa],hist->maxima[pa], hist->minima[pa], world->bayes->deltahist[pa]);
+	      dif = (hist->maxima[pa] - hist->minima[pa]);
+	      if(dif <= 0)
+		hist->bins[pa] = 0;
+	      else
+		hist->bins[pa] = (long) (0.5 + dif / world->bayes->deltahist[pa]) ;
+#ifdef DEBUG_MPI
+	      fprintf(stdout,"%i> LOCUS: bins[%li]=%li = (%f - %f) /%f \n",myID,pa,hist->bins[pa],hist->maxima[pa], hist->minima[pa], world->bayes->deltahist[pa]);
+#endif
 	      hist->binsum += hist->bins[pa];
 	    }
 	}
       else
 	{
-	      hist->bins[pa] = (long) (0.5 + (hist->maxima[pa] - hist->minima[pa]) / world->bayes->deltahist[pa]) ;
-	      hist->binsum += hist->bins[pa];
+	  if(dif <= 0.0)
+	    hist->bins[pa] = 0;
+	  else
+	    hist->bins[pa] = (long) (0.5 + dif / world->bayes->deltahist[pa]) ;
+	  hist->binsum += hist->bins[pa];
 	}
     }
-    // allocate the found number of bins for the histogram
-    world->bayes->histogram[locus].results = (MYREAL *) mycalloc(hist->binsum, sizeof(MYREAL));
-    world->bayes->histogram[locus].set95 = (char *) mycalloc(hist->binsum* 2 + 2, sizeof(char));
-    world->bayes->histogram[locus].set50 = world->bayes->histogram[locus].set95 + hist->binsum + 1;
-    memset(hist->results, 0 , sizeof(MYREAL) * (hist->binsum));    
+  // allocate the found number of bins for the histogram
+  world->bayes->histogram[locus].results = (MYREAL *) mycalloc(hist->binsum, sizeof(MYREAL));
+  world->bayes->histogram[locus].set95 = (char *) mycalloc(hist->binsum* 2 + 2, sizeof(char));
+  world->bayes->histogram[locus].set50 = world->bayes->histogram[locus].set95 + hist->binsum + 1;
+  memset(hist->results, 0 , sizeof(MYREAL) * (hist->binsum));    
 }
 
 /// construct bayes histogram: make a at least BAYESNUMBIN slices through the min-max range for each locus
@@ -1522,6 +1532,7 @@ void find_bayes_min_max(world_fmt* world, MYREAL **mini, MYREAL **maxi, MYREAL *
         {
 #ifdef MPI
 	  maxivalue += BAYESNUMBIN * delta;
+	  minivalue = 0.0; //only good for parameter 0..inf
 #else
 	  maxivalue += BAYESNUMBIN * EPSILON;        
 #endif
@@ -1603,7 +1614,8 @@ void print_locus_histogram(FILE *bayesfile, bayes_fmt * bayes, long locus, long
     MYREAL *maxi = bayes->histogram[locus].maxima;
     char *set50 = bayes->histogram[locus].set50;
     char *set95 = bayes->histogram[locus].set95;
-    
+    if(results == NULL)
+      return;
     for(pa=0; pa < numparam; pa++)
     {
         // if custom migration matrix is set to zero
@@ -2054,67 +2066,69 @@ void bayes_combine_loci(world_fmt * world)
             // this should always work fine without reminder, but rounding error might produce errors
             // therefore the 0.5 addition and flooring
             targetbin = (long) (0.5 + (source->minima[pa] - minima[pa]) / world->bayes->deltahist[pa]);
-            
-            for(sourcebin=0; sourcebin < source->bins[pa]; sourcebin++)
-            {
-                if(source->results[sourcesumbin + sourcebin] > 0.)
-                {
-                    // frequencies are normalized per locus and need adjustment for all loci
-                    count = source->results[sourcesumbin + sourcebin];
-                    results[targetsumbin + targetbin + sourcebin] += log(count);
-                    touched[targetsumbin + targetbin+ sourcebin] = '1';
-                    if(maxval < results[targetsumbin + targetbin + sourcebin])
-                        maxval = results[targetsumbin + targetbin + sourcebin];
-                }
-            }
-            sourcesumbin += source->bins[pa];
-            targetsumbin += target->bins[pa];
-            maxvala[pa] = maxval;
-        }
+            if(source->results != NULL)
+	      {
+		for(sourcebin=0; sourcebin < source->bins[pa]; sourcebin++)
+		  {
+		    if(source->results[sourcesumbin + sourcebin] > 0.)
+		      {
+			// frequencies are normalized per locus and need adjustment for all loci
+			count = source->results[sourcesumbin + sourcebin];
+			results[targetsumbin + targetbin + sourcebin] += log(count);
+			touched[targetsumbin + targetbin+ sourcebin] = '1';
+			if(maxval < results[targetsumbin + targetbin + sourcebin])
+			  maxval = results[targetsumbin + targetbin + sourcebin];
+		      }
+		  }
+		sourcesumbin += source->bins[pa];
+		targetsumbin += target->bins[pa];
+		maxvala[pa] = maxval;
+	      }
+	}
     }
     //
-    // adjust the total and use the overflow safeguard
+    // adjus tthe total and use the overflow safeguard
     targetsumbin = 0;
     for(pa = 0; pa < np; pa++)
-    {
+      {
         // if custom migration matrix for this parameter is set to zero continue
-      if(pa < world->numpop2)
-	{
-	  if(strchr("0c", world->bayes->custm2[pa]))
-            continue;
-	}    
-      target->means[pa] = 0.;
-      sumprob = 0.;
-      //        fprintf(stdout,"== start summary \nprobability   running mean of parameter value\n");
-      for(bin=targetsumbin; bin < targetsumbin + bins[pa]; bin++)
-        {
-          //  fprintf(stdout,"%6.6li %6.6f %20.20f ", bin, minima[pa] + (bin-targetsumbin)/bins[pa] * (maxima[pa]-minima[pa]), results[bin]);
-	  if(touched[bin]=='1')
-            {
-	      results[bin] = EXP(results[bin] - maxvala[pa]);
-	      sumprob += results[bin];
-            }
-	  else
-            {
-	      results[bin] = 0.;
-            }
+	if(pa < world->numpop2)
+	  {
+	    if(strchr("0c", world->bayes->custm2[pa]))
+	      continue;
+	  }    
+	target->means[pa] = 0.;
+	sumprob = 0.;
+	//        fprintf(stdout,"== start summary \nprobability   running mean of parameter value\n");
+	for(bin=targetsumbin; bin < targetsumbin + bins[pa]; bin++)
+	  {
+	    //  fprintf(stdout,"%6.6li %6.6f %20.20f ", bin, minima[pa] + (bin-targetsumbin)/bins[pa] * (maxima[pa]-minima[pa]), results[bin]);
+	    if(touched[bin]=='1')
+	      {
+		results[bin] = EXP(results[bin] - maxvala[pa]);
+		sumprob += results[bin];
+	      }
+	    else
+	      {
+		results[bin] = 0.;
+	      }
             //fprintf(stdout,"%20.20f %20.20f %20.20f\n", results[bin], sumprob, maxvala[pa]);
-        }
+	  }
         total = 0;
         for(bin=targetsumbin; bin < targetsumbin + target->bins[pa]; bin++)
-        {
+	  {
             if(touched[bin]=='1')
-            {
+	      {
                 results[bin] /= sumprob;
                 total +=  results[bin];
                 target->means[pa] += results[bin] * (minima[pa] +  world->bayes->deltahist[pa]/2. 
 						     + world->bayes->deltahist[pa] * (bin-targetsumbin));
-            }
+	      }
             //fprintf(stdout,"%5.5li %20.20f %20.20f\n", bin, results[bin], total);
-        }
+	  }
 	//        fprintf(stdout,"== end summary \n");
         targetsumbin += bins[pa];
-    }
+      }
     free (touched);
     free(maxvala);
     
