@@ -15,7 +15,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: combroyden.h,v 1.26 2004/10/24 20:53:17 beerli Exp $
+$Id: combroyden.h 175 2005-12-02 14:51:23Z beerli $
  
 -------------------------------------------------------*/
 
@@ -52,7 +52,9 @@ extern void setup_parameter0_standard (world_fmt * world, nr_fmt * nr,
 
 extern void combine_gradient (nr_fmt * nr, helper_fmt * helper, MYREAL *gxv);
 
-extern long maximize (MYREAL **thisparam, world_fmt * world, nr_fmt * nr,
+extern long maximize (MYREAL **thisparam, world_fmt * world, 
+		      nr_fmt * nr,
+		      MYREAL **hess,
                           long analystype, long repkind);
 extern void set_logparam (MYREAL *loga, MYREAL *a, long size);
 extern void set_expparam (MYREAL *expa, MYREAL *a, long size);
