@@ -22,7 +22,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 175 2005-12-02 14:51:23Z beerli $
+$Id: data.c 228 2006-01-19 19:13:57Z beerli $
  
 -------------------------------------------------------*/
 /*! \file data.c
@@ -106,14 +106,71 @@ init_data (data_fmt * data)
 {
  
 }
- 
+*/
+
+///
+/// free the data module 
 void
 destroy_data (data_fmt * data)
 {
+  long ind;
+  long indalloc;
+  long locus;
+  long pop;
+  long loci = data->loci;
+  long numpop = data->numpop;
+
+  // free data from init_data_structure3
+  for (locus = 0; locus < loci; locus++)
+    {
+      free(data->allele[locus]);
+    }
+  free(data->allele);
+  free(data->maxalleles);
+  free(data->skiploci);
+
+  // free data from init_data_structure2
+  for(pop=0; pop < numpop ; pop++)
+    {
+      indalloc = -1;
+      for(locus=0; locus < loci; locus++)
+	{
+	  if(indalloc < data->numind[pop][locus])
+	    indalloc = data->numind[pop][locus];
+	}
+      for (ind = 0; ind < indalloc; ind++)
+	{
+	  free(data->indnames[pop][ind]);
+	  free(data->yy[pop][ind]);
+	}
+      free(data->indnames[pop]);
+      free(data->yy[pop]);
+    }
+  free(data->indnames);
+  free(data->yy);
+
+  // data->yy were already freed in free_datapart()
+
+  // free data from init_structure_1
+  free (data->popnames[0]);
+  free (data->numind[0]);
+  free (data->numalleles[0]);
+  free (data->popnames);
+  free (data->numind);
+  free (data->numalleles);
+  free (data->seq->sites);
+  free (data->seq);
+  free (data->geo);
+  free (data->lgeo);
+  if(data->ogeo != NULL)
+    {
+      free (data->ogeo[0]);
+      free (data->ogeo);
+    }
   free (data);
 }
  
-*/
+
 
 void
 get_data (FILE * infile, data_fmt * data, option_fmt * options)
@@ -190,28 +247,30 @@ void
 init_data_structure1 (data_fmt ** data, option_fmt * options)
 {
     long pop;
+    long numpop = (*data)->numpop;
+    long loci   = (*data)->loci;
+    
+    (*data)->ogeo = NULL;
+    (*data)->geo = NULL;
     if ((*data)->yy == NULL)
     {
-        (*data)->yy =
-            (char *****) mymalloc (sizeof (char ****) * (*data)->numpop);
+        (*data)->yy = (char *****) mymalloc (sizeof (char ****) * numpop);
         (*data)->seq = (seqmodel_fmt *) mycalloc (1, sizeof (seqmodel_fmt));
-        (*data)->popnames =
-            (char **) mymalloc (sizeof (char *) * (*data)->numpop);
-        (*data)->indnames =
-            (char ***) mymalloc (sizeof (char **) * (*data)->numpop);
-        (*data)->numind = (long **) mymalloc (sizeof (long *) * (*data)->numpop);
-        (*data)->numalleles = (long **) mymalloc (sizeof (long *) * (*data)->numpop);
-        for (pop = 0; pop < (*data)->numpop; pop++)
+        (*data)->popnames =(char **) mymalloc (sizeof (char *) * numpop);
+        (*data)->popnames[0] =(char *) mycalloc (numpop * LINESIZE,sizeof(char));
+        (*data)->indnames = (char ***) mymalloc (sizeof (char **) * numpop);
+        (*data)->numind = (long **) mymalloc (sizeof (long *) * numpop);
+        (*data)->numind[0] = (long *) mymalloc (sizeof (long) * numpop * loci);
+        (*data)->numalleles = (long **) mymalloc (sizeof (long *) * numpop);
+        (*data)->numalleles[0] = (long *) mymalloc (sizeof (long) * numpop * loci);
+
+        for (pop = 1; pop < numpop; pop++)
         {
-            (*data)->popnames[pop] =
-                (char *) mycalloc (1, sizeof (char) * LINESIZE);
-            (*data)->numind[pop] =
-                (long *) mymalloc (sizeof (long) * (*data)->loci);
-            (*data)->numalleles[pop] =
-                (long *) mymalloc (sizeof (long) * (*data)->loci);
+	  (*data)->popnames[pop] = (*data)->popnames[0] + pop * LINESIZE;
+	  (*data)->numind[pop] = (*data)->numind[0] + pop * loci;
+	  (*data)->numalleles[pop] =  (*data)->numalleles[0] + pop * loci;
         }
-        (*data)->seq->sites =
-            (long *) mycalloc (1, sizeof (long) * (*data)->loci);
+        (*data)->seq->sites = (long *) mycalloc (1, sizeof (long) * loci);
     }
     else
     {
@@ -271,9 +330,9 @@ free_datapart (data_fmt * data, option_fmt * options, long locus)
     //  long genomes = number_genomes (options->datatype);
     for (pop = 0; pop < data->numpop; pop++)
     {
-        for (ind = 0; ind < data->numalleles[pop][locus]; ind++)
+        for (ind = 0; ind < data->numind[pop][locus]; ind++)
         {
-            if (strchr (SEQUENCETYPES, options->datatype))
+            if (!strchr (SEQUENCETYPES, options->datatype))
             {
                 free (data->yy[pop][ind][locus][0]);
                 free (data->yy[pop][ind][locus][1]);
