@@ -17,7 +17,7 @@
   
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
-$Id: definitions.h 178 2005-12-02 22:11:20Z beerli $
+$Id: definitions.h 230 2006-01-22 15:18:01Z beerli $
  
   *----------------------------------------------------------------
   */
@@ -137,6 +137,9 @@ $Id: definitions.h 178 2005-12-02 22:11:20Z beerli $
 #define PRETTY_P99 1
 #define PRETTY_P99MAX 3
 #define PRETTY_P100 4
+#define THETAPRIOR 0
+#define MIGPRIOR   1
+#define RATEPRIOR  2
 #ifdef __STDIO_LOADED
 #define VMS
 #define MACHINE_TYPE "VAX/VMS C"
@@ -192,7 +195,7 @@ void vax_tweak_fmt (char *);
 /*if we use this then we guard against allocation problems */
 /* redefinitions of calloc, malloc, realloc are in sighandler.h*/
 #ifdef HAVE_MALLOCWRAP
-//#define LAMARC_MALLOC
+#define LAMARC_MALLOC
 #endif
 
 #ifdef HAVE_DEBUGMPI
@@ -338,9 +341,10 @@ long chains is used */
 #define ATOF(a) strtod((a),(char **) NULL, 10)
 
 /* prior setting */
-#define MULTPRIOR 3
-#define WEXPPRIOR 2
-#define EXPPRIOR 1
+#define GAMMAPRIOR   4
+#define MULTPRIOR    3
+#define WEXPPRIOR    2
+#define EXPPRIOR     1
 #define UNIFORMPRIOR 0
 
 /* theta (4 Ne mu) related material */
@@ -348,7 +352,7 @@ long chains is used */
 #define SMALLEST_THETA    1e-10
 #define DNA_GUESS_THETA    0.01
 #define BIGGEST_THETA      1e4
-#define SMALLEST_MIGRATION 1      /*m/mu equally likely*/
+#define SMALLEST_MIGRATION 0.000001  
 #define DNA_GUESS_MIG      100
 #define BIGGEST_MIGRATION   10e9 
 // defines the value that is used as a minimum summary statistic for migration events on all trees
@@ -358,7 +362,7 @@ long chains is used */
 #define MINMIGSUMSTAT 0.000001
 /* the migration limit is per population, should be plenty
    for moderate sample sizes */
-#define MIGRATION_LIMIT     5000
+#define MIGRATION_LIMIT    100
 #define SMALLEST_PROB     1e-100
 #define SMALLEST_GAMMA      1e-3
 #define BIGGEST_GAMMA        1e9
@@ -458,7 +462,8 @@ long chains is used */
 #define MLE 0
 #define ARBITRARY 1
 #define MAXPOP   100  /*n*(n-1)+n) */
-#define MAXPARAM 10000
+#define MAXPARAM 20000
+#define LNMAXPARAM 9.9034875525361280455 
 #define HEADER 1
 #define NOHEADER 0
 /* migration histogram material*/
