@@ -11,7 +11,7 @@ This software is distributed free of charge for non-commercial use
 and is copyrighted. Of course, we do not guarantee that the software
 works and are not responsible for any damage you may cause or have.
  
-$Id: heating.c,v 1.23 2004/08/28 19:59:31 beerli Exp $
+$Id: heating.c 175 2005-12-02 14:51:23Z beerli $
  
 */
 /*! \file heating.c 
@@ -323,8 +323,8 @@ void adjust_temperatures(world_fmt ** universe, long hchains, long step, long st
                     delta[i-1] *= smaller;
                 else
                 {
-                    if(universe[i-1]->treeswapcount >= HEATSWAPHIGH)
-                        delta[i-1] *= bigger;
+                    if(delta[i-1]<1000 && universe[i-1]->treeswapcount >= HEATSWAPHIGH)
+			  delta[i-1] *= bigger;
                 }
             }
             universe[0]->heat = 1.;
