@@ -11,20 +11,20 @@
    - Hermite (approximates a normal and is activated when 
      the shape parameter alpha is > 100.)
  
-   Part of Migrate (Lamarc package)
-   http://evolution.genetics.washington.edu/lamarc.html
+   Part of Migrate
+   http://popgen.csit.fsu.edu/migrate.html
  
    Peter Beerli, Seattle 2001
    
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
-Copyright 2003-2004 Peter Beerli, Tallahassee FL
+Copyright 2003-2005 Peter Beerli, Tallahassee FL
  
  
  This software is distributed free of charge for non-commercial use
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: laguerre.c,v 1.14 2005/01/21 16:48:34 beerli Exp $
+$Id: laguerre.c 175 2005-12-02 14:51:23Z beerli $
 */
 /* \file laguerre.c
 Calculates the Laguerre Quadrature points, used for gamma deviated site rate variation
