@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 241 2006-01-23 20:42:08Z beerli $
+/* $Id: main.c 267 2006-02-19 18:13:34Z beerli $
 * $Log: main.c,v $
 * Revision 1.114  2005/05/26 14:42:23  beerli
 * man changes most of which I don't remember , try to move to SVN and daily
@@ -340,6 +340,9 @@ main (int argc, char **argv)
     MPI_Comm_create (comm_world, worker_group, &comm_workers);
     if (myID != MASTER)
         MPI_Comm_rank (comm_workers, &myRepID);
+    // locus counter for workers, this should report the number of loci 
+    // each nodes really works on
+    locidone = 0;
 
     MYMPIBARRIER (comm_world);
 #ifdef SLOWNET
@@ -543,12 +546,12 @@ main (int argc, char **argv)
         MYMPIBARRIER (comm_world);
         MPI_Finalize ();
 #endif /*MPI*/
-	free(seed);
-	free(newseed);
-	free(generator);
-        free_universe(universe, usize, options);
-	destroy_data(data);
-	destroy_options(options);
+	//	free(seed);
+	//free(newseed);
+	//free(generator);
+        //free_universe(universe, usize, options);
+	//destroy_data(data);
+	//destroy_options(options);
         return 0;
 }				/* main end */
 
@@ -751,7 +754,7 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
     
     if (myID == MASTER)
     {
-        mpi_runloci_master (data->loci, EARTH->who, EARTH);
+        mpi_runloci_master (data->loci, EARTH->who, EARTH, options->readsum);
 #ifndef MPIREPLICANT
         sent = mpi_send_stop_mcmc_worker (numcpu, data->loci, &comm_world, irequests,istatus, myID);
 
@@ -766,7 +769,7 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
         // the first worker will always be here waiting 
         if (myID == FIRSTWORKER)
         {
-            MYMPIRECV (twolongs, TWO, MPI_LONG, MASTER, 0, comm_world, &status);
+	  MYMPIRECV (twolongs, TWO, MPI_LONG, MASTER, 0, comm_world, &status);
 #ifdef MPI_DEBUG
 	    fprintf(stdout,"%i> FIRSTWORKER kill off now non-loci-worker\n",myID);
 #endif
@@ -982,13 +985,16 @@ void
 print_heating_progress (world_fmt ** universe, worldoption_fmt * options,
                         long stepinc)
 {
-    
+  MYREAL fstepinc = (MYREAL) stepinc;
     if (options->heating)
     {
-        universe[0]->accept_freq /= stepinc;
-        universe[1]->accept_freq /= stepinc;
-        universe[2]->accept_freq /= stepinc;
-        universe[3]->accept_freq /= stepinc;
+#ifdef DEBUG_MPI
+      printf("%i> stepinc=%li =========\n",myID, stepinc);
+#endif
+        universe[0]->accept_freq /= fstepinc;
+        universe[1]->accept_freq /= fstepinc;
+        universe[2]->accept_freq /= fstepinc;
+        universe[3]->accept_freq /= fstepinc;
         if (options->progress)
             print_heating_progress2 (stdout, options, universe);
         if (options->writelog)
@@ -1011,34 +1017,38 @@ print_heating_progress (world_fmt ** universe, worldoption_fmt * options,
     }
 }
 
-
-/// sub-function of print_heating
+///
+/// sub-function of print_heating, in MPI mode, the string printing will minimize data transfer.
 void
 print_heating_progress2 (FILE * file, worldoption_fmt * options,
                          world_fmt ** universe)
 {
-    FPRINTF (file, "           Swapping between %li temperatures.\n",
-             options->heated_chains);
-    if (options->heated_chains > 4)
-        FPRINTF (file, "               Only the 4 coldest chains are shown\n");
-    FPRINTF (file,
-             "           Temperature | Accepted |  Swaps between temperatures\n");
-    if (options->heated_chains > 4)
-        FPRINTF (file, "           %10.4f  |   %4.2f   |    %5li||\n",
-                 universe[3]->averageheat, universe[3]->accept_freq,
-                 universe[3]->swapped);
-    else
-        FPRINTF (file, "           %10.4f  |   %4.2f   |          |\n",
-                 universe[3]->averageheat, universe[3]->accept_freq);
-    FPRINTF (file, "           %10.4f  |   %4.2f   |    %5li ||\n",
-             universe[2]->averageheat, universe[2]->accept_freq,
-             universe[2]->swapped);
-    FPRINTF (file, "           %10.4f  |   %4.2f   |    %5li  ||\n",
-             universe[1]->averageheat, universe[1]->accept_freq,
-             universe[1]->swapped);
-    FPRINTF (file, "           %10.4f  |   %4.2f   |    %5li   |\n",
-             universe[0]->averageheat, universe[0]->accept_freq,
-             universe[0]->swapped);
+  char *plog;
+  long plogsize = 0L;
+  plog = (char *) mycalloc(LONGLINESIZE,sizeof(char));
+  
+  plogsize = sprintf(plog, "           Swapping between %li temperatures.\n", options->heated_chains);
+  if (options->heated_chains > 4)
+    plogsize += sprintf (plog + plogsize, "               Only the 4 coldest chains are shown\n");
+  plogsize += sprintf (plog + plogsize,"           Temperature | Accepted |  Swaps between temperatures\n");
+  if (options->heated_chains > 4)
+    plogsize += sprintf (plog + plogsize, "           %10.4f  |   %4.2f   |    %5li||\n",
+			 universe[3]->averageheat, universe[3]->accept_freq,
+			 universe[3]->swapped);
+  else
+    plogsize += sprintf (plog + plogsize, "           %10.4f  |   %4.2f   |          |\n",
+			 universe[3]->averageheat, universe[3]->accept_freq);
+  plogsize += sprintf (plog + plogsize, "           %10.4f  |   %4.2f   |    %5li ||\n",
+		       universe[2]->averageheat, universe[2]->accept_freq,
+		       universe[2]->swapped);
+  plogsize += sprintf (plog + plogsize,"           %10.4f  |   %4.2f   |    %5li  ||\n",
+		       universe[1]->averageheat, universe[1]->accept_freq,
+		       universe[1]->swapped);
+  plogsize += sprintf (plog + plogsize,"           %10.4f  |   %4.2f   |    %5li   |\n",
+		       universe[0]->averageheat, universe[0]->accept_freq,
+		       universe[0]->swapped);
+  FPRINTF(file,"%s",plog);
+  free(plog);
 }
 
 
@@ -1129,7 +1139,10 @@ analyze_olddata (world_fmt * world,
 #endif
         
 #ifdef MPI
-        mpi_runloci_master (world->loci, world->who, world);
+	MYMPIBARRIER(comm_world);
+	printf("%i> before mpi_runlocimaster\n",myID);fflush(stdout);
+	mpi_runloci_master (world->loci, world->who, world, options->readsum);
+	
 #else
         
         for (locus = 0; locus < world->loci; locus++)
@@ -1155,7 +1168,10 @@ analyze_olddata (world_fmt * world,
 #ifdef MPI
     else
     {
-        assignloci_worker (world);
+      MYMPIBARRIER(comm_world);
+      printf("%i> before assignloci_worker\n",myID);fflush(stdout);
+      assignloci_worker (world, options, &Gmax);
+      // some workers might still wait in assignloci_worker(), will be stopped through the master
     }
 #endif
     return Gmax;
