@@ -17,7 +17,7 @@
   and is copyrighted. Of course, we do not guarantee that the software
   works and are not responsible for any damage you may cause or have.
 
-  $Id: menu.c 227 2006-01-19 04:31:25Z beerli $
+  $Id: menu.c 242 2006-01-23 21:09:17Z beerli $
 
   -------------------------------------------------------*/
 #include "migration.h"
@@ -292,39 +292,41 @@ print_title(world_fmt * world, option_fmt * options)
 {
   char            nowstr[LINESIZE];
   long            len = 45, i, filepos = -1;
-  if (!world->options->simulation) {
-    FPRINTF(world->outfile, "  ");
-    if (options->title[0] != '\0') {
-      len = (long) MAX(strlen(options->title), 45);
+  if (!world->options->simulation) 
+    {
+      FPRINTF(world->outfile, "  ");
+      if (options->title[0] != '\0') 
+	{
+	  len = (long) MAX(strlen(options->title), 45);
+	  for (i = 0; i < len; i++)
+	    FPRINTF(world->outfile, "=");
+	  FPRINTF(world->outfile, "\n  %-*.*s\n  ", (int) len, (int) len,options->title);
+	}
       for (i = 0; i < len; i++)
 	FPRINTF(world->outfile, "=");
-      FPRINTF(world->outfile, "\n  %-*.*s\n  ", (int) len, (int) len,options->title);
-    }
-    for (i = 0; i < len; i++)
-      FPRINTF(world->outfile, "=");
-
-    FPRINTF(world->outfile,
-	    "\n  MIGRATION RATE AND POPULATION SIZE ESTIMATION\n");
-    FPRINTF(world->outfile,
-	    "  using Markov Chain Monte Carlo simulation\n  ");
-
-    for (i = 0; i < len; i++)
-      FPRINTF(world->outfile, "=");
-    FPRINTF(world->outfile, "\n  Version %s\n", MIGRATEVERSION);
-    get_time(nowstr, "%c");
-    if (nowstr[0] != '\0') {
-      FPRINTF(world->outfile, "\n  Program started at %s\n", nowstr);
-      filepos = ftell(world->outfile);
-      /*
-       * DO NOT REMOVE the blanks in the following print
-       * statement, they are overwritten at the program end
-       * with the timestamp
-       */
+      
       FPRINTF(world->outfile,
-	      "                                                   \n");
+	      "\n  MIGRATION RATE AND POPULATION SIZE ESTIMATION\n");
+      FPRINTF(world->outfile,
+	      "  using Markov Chain Monte Carlo simulation\n  ");
+      
+      for (i = 0; i < len; i++)
+	FPRINTF(world->outfile, "=");
+      FPRINTF(world->outfile, "\n  Version %s\n", MIGRATEVERSION);
+      get_time(nowstr, "%c");
+      if (nowstr[0] != '\0') {
+	FPRINTF(world->outfile, "\n  Program started at %s\n", nowstr);
+	filepos = ftell(world->outfile);
+	/*
+	 * DO NOT REMOVE the blanks in the following print
+	 * statement, they are overwritten at the program end
+	 * with the timestamp
+	 */
+	FPRINTF(world->outfile,
+		"                                                   \n");
+      }
+      FPRINTF(world->outfile, "\n\n");
     }
-    FPRINTF(world->outfile, "\n\n");
-  }
   return filepos;
 }
 
