@@ -10,7 +10,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-  $Id: mig-histogram.c 224 2006-01-14 21:44:17Z beerli $
+  $Id: mig-histogram.c 247 2006-01-28 16:48:46Z beerli $
  
  */
 /*! \file mig-histogram.c
@@ -513,6 +513,8 @@ increase_mighist (mighistloci_fmt * mighistlocus)
                 i < mighistlocus->allocsize; i++)
         {
             mighistlocus->mighist[i].migeventsize = 0;
+	    mighistlocus->mighist[i].copies = 0;
+	    mighistlocus->mighist[i].weight = 0;
             mighistlocus->mighist[i].allocsize = DEFAULTALLOCSIZE;
             mighistlocus->mighist[i].migevents =
                 (migevent_fmt *) mycalloc (DEFAULTALLOCSIZE, sizeof (migevent_fmt));
