@@ -52,7 +52,7 @@ extern int profiledone;
 
 extern void broadcast_options (option_fmt * options);
 
-extern void mpi_runloci_master (long loci, int *who, world_fmt *world);
+extern void mpi_runloci_master (long loci, int *who, world_fmt *world, boolean options_readsum);
 
 extern void mpi_runloci_worker (world_fmt ** universe, int usize,
                                     option_fmt * options, data_fmt * data,
@@ -110,7 +110,7 @@ extern void mpi_gmax_worker(world_fmt * world);
 
 extern void mpi_send_stop (world_fmt * world);
 extern void mpi_results_stop (void);
-extern void assignloci_worker (world_fmt * world);
+extern void assignloci_worker (world_fmt * world, option_fmt *options, long * Gmax);
 void setup_parameter0_mpi (world_fmt * world, nr_fmt * nr, long repkind,
                            long repstart, long repstop, long loci, long kind,
                            boolean multilocus);
