@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 175 2005-12-02 14:51:23Z beerli $
+  $Id: migration.h 215 2006-01-03 00:03:51Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -195,15 +195,16 @@ typedef struct _bayeshistogram
 /// holds data for Bayesian approach
 typedef struct _bayes
 {
-    long count;
-    MYREAL *datastore; //data store for
-    // pointers into datastore
-    MYREAL *priormean; // holds the means of priors
-    MYREAL *delta; // change scale [how big can this be
-    MYREAL *minparam;// minimal allowed parameter value
-    MYREAL *maxparam; // maximal allowed parameter value
-    MYREAL *meanparam; // mean values for expprior
-    // record all changes of parameters
+  long count;
+  long numpop2;
+  MYREAL *datastore; //data store for
+  // pointers into datastore
+  MYREAL *priormean; // holds the means of priors
+  MYREAL *delta; // change scale [how big can this be
+  MYREAL *minparam;// minimal allowed parameter value
+  MYREAL *maxparam; // maximal allowed parameter value
+  MYREAL *meanparam; // mean values for expprior
+  // record all changes of parameters
     MYREAL **params;  // save for parameter vectors
     long allocparams; //number of allocated parameter vectors
     long numparams;  //number of saved parameter vectors
@@ -217,6 +218,7 @@ typedef struct _bayes
   bayeshistogram_fmt *histogram;
   MYREAL *deltahist; // delta for all histograms per parameters [important for multilocus case 
   char * custm2; //pointer to the world->options->custm2;
+  boolean mu;
   long mdiminterval ; // interval at which the whole parameter list is printed to file
   int prettyhist;
 }
@@ -376,10 +378,11 @@ typedef struct _option
     /* mcmc options */
     boolean bayes_infer;
     MYREAL updateratio;
-    int bayesprior;
+    int bayesprior[3];
   int bayespretty;
     prior_fmt *bayespriortheta;
     prior_fmt *bayespriorm;
+    prior_fmt *bayespriorrate;
     bayes_fmt *bayes;
   boolean has_bayesfile;
   boolean has_bayesmdimfile;
@@ -387,7 +390,8 @@ typedef struct _option
     short thetaguess;
     short migrguess;
     boolean gamma;
-    boolean murates;
+  boolean murates;
+  boolean bayesmurates;
     MYREAL alphavalue;
     MYREAL *mu_rates;
     long muloci;
