@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c,v 1.52 2004/08/28 19:59:34 beerli Exp $
+ $Id: sequence.c 175 2005-12-02 14:51:23Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
@@ -1671,7 +1671,7 @@ treelike_seq (world_fmt * world, long locus)
             scale = p->scale[i];
             stterm =  vector_multiply(&freq.v, x1);
             summ += seq->aliasweight[i] * (log (stterm) + scale);
-            if(isnan(summ))
+            if(MYISNAN(summ))
                 error("F..... ahem Fehler\n");
         }
 #else
@@ -1713,7 +1713,7 @@ treelike_seq (world_fmt * world, long locus)
             swap (clai, world->contribution[i]);
             //      memcpy (world->contribution[i], clai, size);
             summ += seq->aliasweight[i] * lterm;
-            if(isnan(summ))
+            if(MYISNAN(summ))
                 error("F..... ahem Fehler\n");
 
         }
