@@ -22,7 +22,7 @@
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-   $Id: sighandler.c 185 2005-12-17 02:27:12Z beerli $                  
+   $Id: sighandler.c 257 2006-02-11 19:13:05Z beerli $                  
    ----------------------------------------------------- */
 /*! \file sighandler.c */
 #include "sighandler.h"
@@ -359,6 +359,17 @@ void *
 LAMARC_malloc (size_t size, const char file[], const long line)
 {
     void *x;
+    size_t newsize;
+    if(size == 0)
+      {
+        fprintf (stderr,
+                 "%i> WARNING in memory allocation (malloc(%li)) in file %s on line %li\n",
+                 myID, (long) size, file, line);
+	newsize = 1;
+      }
+    else
+      newsize = size;
+
     x = malloc (size);
 //#ifdef MEMDEBUG
 //    fprintf(stderr,"malloc: %li \n",(long) size);
@@ -385,6 +396,17 @@ LAMARC_calloc (size_t repeats, size_t size,
                const char file[], const long line)
 {
     void *x;
+    size_t newsize;
+    if(size == 0)
+            {
+        fprintf (stderr,
+                 "%i> WARNING in memory allocation (malloc(%li)) in file %s on line %li\n",
+                 myID, (long) size, file, line);
+	newsize = 1;
+      }
+    else
+      newsize = size;
+
     x = calloc (repeats, size);
 //#ifdef MEMDEBUG
 //    fprintf(stderr,"calloc: %li x %li = %li\n",(long) repeats, (long) size, (long)(repeats * size));
@@ -410,6 +432,16 @@ LAMARC_realloc (void *ptr, size_t size, const char file[],
                 const long line)
 {
     void *x;
+    size_t newsize;
+    if(size == 0)
+            {
+        fprintf (stderr,
+                 "%i> WARNING in memory allocation (malloc(%li)) in file %s on line %li\n",
+                 myID, (long) size, file, line);
+	newsize = 1;
+      }
+    else
+      newsize = size;
     x = realloc (ptr, size);
 //#ifdef MEMDEBUG
 //    fprintf(stderr,"realloc:  %li\n",(long) size);
