@@ -20,7 +20,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 175 2005-12-02 14:51:23Z beerli $
+$Id: tools.c 220 2006-01-10 19:00:59Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 #include "migration.h"
@@ -584,6 +584,10 @@ void unread_word(FILE *infile, char *word)
     }
 }
 
+#ifdef STRANGEDEBUG
+extern int errno;
+#endif
+
 /// opns a file for reading or writing
 void
 openfile (FILE ** fp, char *filename, char *mode, char *perm)
@@ -599,14 +603,22 @@ openfile (FILE ** fp, char *filename, char *mode, char *perm)
     strncpy (file, filename, LINESIZE - 1);
     while (trials++ < 10)
     {
-        of = fopen (file, mode);
+      of = fopen (file, mode);
+#ifdef STRANGEDEBUG
+      fprintf(stdout,"original filename -->%s<--\n",filename);
+      fprintf(stdout,"used filename     -->%s<--\n",file);
+#endif
         if (of!=NULL)
             break;
         else
         {
+#ifdef STRANGEDEBUG
+	  fprintf(stdout,"mode              -->%s<--\n", mode);
+	  fprintf(stdout,"errorcode         -->%i<--\n",errno);
+#endif
             switch (*mode)
-            {
-            case 'r':
+	      {
+	      case 'r':
 #ifdef MPI
 
                 printf("%i> ",myID);
@@ -1038,7 +1050,7 @@ insert_migr_node (world_fmt * world, node * up, node * down,
         oldNode = up;
         theNode = up->back;
         panic = 0;
-        while (theNode->tyme < migr_table[i].time && panic++ < 10000)
+        while (theNode->tyme < migr_table[i].time /*&& panic++ < 10000*/)
         {
             if (theNode->tip && theNode->type != 'r')
             {
